@@ -99,20 +99,27 @@ class SourcePackage(object):
             bug.subscribe(person=launchpad.me)
             Logger.info("Subscribed me to bug #%i.", bug.id)
 
-            bug.unsubscribe(person=launchpad.people['ubuntu-sponsors'])
-            Logger.info("Unsubscribed ubuntu-sponsors from bug #%i.", bug.id)
+            sponsorsteam = launchpad.people['ubuntu-sponsors']
+            for sub in bug.subscriptions:
+                if sub.person == sponsorsteam and sub.canBeUnsubscribedByUser():
+                    bug.unsubscribe(person=launchpad.people['ubuntu-sponsors'])
+                    Logger.info("Unsubscribed ubuntu-sponsors from bug #%i.",
+                                bug.id)
+                elif sub.person == sponsorsteam:
+                    Logger.info("Couldn't unsubscribe ubuntu-sponsors from "
+                                "bug #%i.", bug.id)
 
             Logger.normal("Successfully acknowledged sync request bug #%i.",
                           bug.id)
         else:
-            Logger.error("Acknowledging a sync request other than to the "
-                         "official Ubuntu archive is not supported!")
+            Logger.error("Sync requests can only be acknowledged when the "
+                         "upload target is Ubuntu.")
             sys.exit(1)
         return True
 
     def ask_and_upload(self, upload):
         """Ask the user before uploading the source package.
-        
+
         Returns true if the source package is uploaded successfully. Returns
         false if the user wants to change something.
         """
